/*
** Module   : RemoteResourceImpl.java
** Abstract : Implementation of a remote resource. 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130611 Created initial version.
*/

package com.goldencode.p2j.util;

import java.io.*;

/**
 * This implementation is used to either transport resource IDs during appserver calls from one
 * side to another or, on requester side, to identify a resource as being remote.
 */
public class RemoteResourceImpl
extends TransparentWrapper
implements RemoteResource,
           Externalizable
{
   /**
    * Instantiate this remote resource by saving its resource ID.
    * 
    * @param    resourceId
    *           The remote resource ID.
    */
   public RemoteResourceImpl(String resourceId)
   {
      super(resourceId);
   }

   /**
    * Get the ID of this remote resource.
    * 
    * @return   See above.
    */
   public String getResourceId()
   {
      return (String) get();
   }

   /**
    * Read the resource ID from the specified input source.
    * 
    * @param    in
    *           The input source from which the resource ID will be read.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   public void readExternal(ObjectInput in)
   throws IOException
   {
      referent = in.readUTF();
   }

   /**
    * Send the resource ID to the specified output destination.
    * 
    * @param    out
    *           The output destination to which the resource ID will be sent.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      out.writeUTF(getResourceId());
   }
}
